==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/gamelift_fleet/GameliftFleetResourceCreationLimitPolicy.java <==
package com.hashicorp.cdktf.providers.aws.gamelift_fleet;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:54.046Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.gameliftFleet.GameliftFleetResourceCreationLimitPolicy")
@software.amazon.jsii.Jsii.Proxy(GameliftFleetResourceCreationLimitPolicy.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface GameliftFleetResourceCreationLimitPolicy extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#new_game_sessions_per_creator GameliftFleet#new_game_sessions_per_creator}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getNewGameSessionsPerCreator() {
        return null;
    }

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#policy_period_in_minutes GameliftFleet#policy_period_in_minutes}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getPolicyPeriodInMinutes() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link GameliftFleetResourceCreationLimitPolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link GameliftFleetResourceCreationLimitPolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<GameliftFleetResourceCreationLimitPolicy> {
        java.lang.Number newGameSessionsPerCreator;
        java.lang.Number policyPeriodInMinutes;

        /**
         * Sets the value of {@link GameliftFleetResourceCreationLimitPolicy#getNewGameSessionsPerCreator}
         * @param newGameSessionsPerCreator Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#new_game_sessions_per_creator GameliftFleet#new_game_sessions_per_creator}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder newGameSessionsPerCreator(java.lang.Number newGameSessionsPerCreator) {
            this.newGameSessionsPerCreator = newGameSessionsPerCreator;
            return this;
        }

        /**
         * Sets the value of {@link GameliftFleetResourceCreationLimitPolicy#getPolicyPeriodInMinutes}
         * @param policyPeriodInMinutes Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#policy_period_in_minutes GameliftFleet#policy_period_in_minutes}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder policyPeriodInMinutes(java.lang.Number policyPeriodInMinutes) {
            this.policyPeriodInMinutes = policyPeriodInMinutes;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GameliftFleetResourceCreationLimitPolicy}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public GameliftFleetResourceCreationLimitPolicy build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link GameliftFleetResourceCreationLimitPolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GameliftFleetResourceCreationLimitPolicy {
        private final java.lang.Number newGameSessionsPerCreator;
        private final java.lang.Number policyPeriodInMinutes;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.newGameSessionsPerCreator = software.amazon.jsii.Kernel.get(this, "newGameSessionsPerCreator", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.policyPeriodInMinutes = software.amazon.jsii.Kernel.get(this, "policyPeriodInMinutes", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.newGameSessionsPerCreator = builder.newGameSessionsPerCreator;
            this.policyPeriodInMinutes = builder.policyPeriodInMinutes;
        }

        @Override
        public final java.lang.Number getNewGameSessionsPerCreator() {
            return this.newGameSessionsPerCreator;
        }

        @Override
        public final java.lang.Number getPolicyPeriodInMinutes() {
            return this.policyPeriodInMinutes;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getNewGameSessionsPerCreator() != null) {
                data.set("newGameSessionsPerCreator", om.valueToTree(this.getNewGameSessionsPerCreator()));
            }
            if (this.getPolicyPeriodInMinutes() != null) {
                data.set("policyPeriodInMinutes", om.valueToTree(this.getPolicyPeriodInMinutes()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.gameliftFleet.GameliftFleetResourceCreationLimitPolicy"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GameliftFleetResourceCreationLimitPolicy.Jsii$Proxy that = (GameliftFleetResourceCreationLimitPolicy.Jsii$Proxy) o;

            if (this.newGameSessionsPerCreator != null ? !this.newGameSessionsPerCreator.equals(that.newGameSessionsPerCreator) : that.newGameSessionsPerCreator != null) return false;
            return this.policyPeriodInMinutes != null ? this.policyPeriodInMinutes.equals(that.policyPeriodInMinutes) : that.policyPeriodInMinutes == null;
        }

        @Override
        public final int hashCode() {
            int result = this.newGameSessionsPerCreator != null ? this.newGameSessionsPerCreator.hashCode() : 0;
            result = 31 * result + (this.policyPeriodInMinutes != null ? this.policyPeriodInMinutes.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/gamelift_fleet/GameliftFleetResourceCreationLimitPolicy.java <==
package com.hashicorp.cdktf.providers.aws.gamelift_fleet;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:09.904Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.gameliftFleet.GameliftFleetResourceCreationLimitPolicy")
@software.amazon.jsii.Jsii.Proxy(GameliftFleetResourceCreationLimitPolicy.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface GameliftFleetResourceCreationLimitPolicy extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/gamelift_fleet#new_game_sessions_per_creator GameliftFleet#new_game_sessions_per_creator}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getNewGameSessionsPerCreator() {
        return null;
    }

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/gamelift_fleet#policy_period_in_minutes GameliftFleet#policy_period_in_minutes}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getPolicyPeriodInMinutes() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link GameliftFleetResourceCreationLimitPolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link GameliftFleetResourceCreationLimitPolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<GameliftFleetResourceCreationLimitPolicy> {
        java.lang.Number newGameSessionsPerCreator;
        java.lang.Number policyPeriodInMinutes;

        /**
         * Sets the value of {@link GameliftFleetResourceCreationLimitPolicy#getNewGameSessionsPerCreator}
         * @param newGameSessionsPerCreator Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/gamelift_fleet#new_game_sessions_per_creator GameliftFleet#new_game_sessions_per_creator}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder newGameSessionsPerCreator(java.lang.Number newGameSessionsPerCreator) {
            this.newGameSessionsPerCreator = newGameSessionsPerCreator;
            return this;
        }

        /**
         * Sets the value of {@link GameliftFleetResourceCreationLimitPolicy#getPolicyPeriodInMinutes}
         * @param policyPeriodInMinutes Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/gamelift_fleet#policy_period_in_minutes GameliftFleet#policy_period_in_minutes}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder policyPeriodInMinutes(java.lang.Number policyPeriodInMinutes) {
            this.policyPeriodInMinutes = policyPeriodInMinutes;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GameliftFleetResourceCreationLimitPolicy}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public GameliftFleetResourceCreationLimitPolicy build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link GameliftFleetResourceCreationLimitPolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GameliftFleetResourceCreationLimitPolicy {
        private final java.lang.Number newGameSessionsPerCreator;
        private final java.lang.Number policyPeriodInMinutes;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.newGameSessionsPerCreator = software.amazon.jsii.Kernel.get(this, "newGameSessionsPerCreator", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.policyPeriodInMinutes = software.amazon.jsii.Kernel.get(this, "policyPeriodInMinutes", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.newGameSessionsPerCreator = builder.newGameSessionsPerCreator;
            this.policyPeriodInMinutes = builder.policyPeriodInMinutes;
        }

        @Override
        public final java.lang.Number getNewGameSessionsPerCreator() {
            return this.newGameSessionsPerCreator;
        }

        @Override
        public final java.lang.Number getPolicyPeriodInMinutes() {
            return this.policyPeriodInMinutes;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getNewGameSessionsPerCreator() != null) {
                data.set("newGameSessionsPerCreator", om.valueToTree(this.getNewGameSessionsPerCreator()));
            }
            if (this.getPolicyPeriodInMinutes() != null) {
                data.set("policyPeriodInMinutes", om.valueToTree(this.getPolicyPeriodInMinutes()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.gameliftFleet.GameliftFleetResourceCreationLimitPolicy"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GameliftFleetResourceCreationLimitPolicy.Jsii$Proxy that = (GameliftFleetResourceCreationLimitPolicy.Jsii$Proxy) o;

            if (this.newGameSessionsPerCreator != null ? !this.newGameSessionsPerCreator.equals(that.newGameSessionsPerCreator) : that.newGameSessionsPerCreator != null) return false;
            return this.policyPeriodInMinutes != null ? this.policyPeriodInMinutes.equals(that.policyPeriodInMinutes) : that.policyPeriodInMinutes == null;
        }

        @Override
        public final int hashCode() {
            int result = this.newGameSessionsPerCreator != null ? this.newGameSessionsPerCreator.hashCode() : 0;
            result = 31 * result + (this.policyPeriodInMinutes != null ? this.policyPeriodInMinutes.hashCode() : 0);
            return result;
        }
    }
}
